# BomberNight
Uma releitura dark do clássico Bomberman

## Instalação
```
$ pip3 install bombernight
```


## Como jogar
Para iniciar o jogo, digite: 
```
$ bombernight 
```

## Controles
- w ou seta para cima 
- s ou seta para baixo 
- a ou seta para esquerda
- d ou seta para direita
- espaço para colocar bombas
